[jbossws-commits] JBossWS SVN: r10387 - in stack/cxf/branches/ropalka/modules/server/src/main: resources and 1 other directory.

jbossws-commits at lists.jboss.org jbossws-commits at lists.jboss.org
Mon Jul 27 04:21:15 EDT 2009


Author: richard.opalka at jboss.com
Date: 2009-07-27 04:21:15 -0400 (Mon, 27 Jul 2009)
New Revision: 10387

Modified:
   stack/cxf/branches/ropalka/modules/server/src/main/java/org/jboss/wsf/stack/cxf/DescriptorDeploymentAspect.java
   stack/cxf/branches/ropalka/modules/server/src/main/resources/jbossws-cxf-config.xml
Log:
[JBWS-2332] refactoring

Modified: stack/cxf/branches/ropalka/modules/server/src/main/java/org/jboss/wsf/stack/cxf/DescriptorDeploymentAspect.java
===================================================================
--- stack/cxf/branches/ropalka/modules/server/src/main/resources/jbossws-cxf-config.xml	2009-07-27 08:15:17 UTC (rev 10386)
+++ stack/cxf/branches/ropalka/modules/server/src/main/resources/jbossws-cxf-config.xml	2009-07-27 08:21:15 UTC (rev 10387)
@@ -29,7 +29,8 @@
     <property name="provides">ContextProperties</property>
     <property name="contextProperties">
       <map keyClass="java.lang.String" valueClass="java.lang.String">
-        <entry><key>org.jboss.ws.webapp.ServletClass</key><value>org.jboss.wsf.stack.cxf.CXFServletExt</value></entry>
+        <entry><key>org.jboss.wsf.common.integration.Constants.StackTransportClass</key>
+        <value>org.jboss.wsf.stack.cxf.CXFServletExt</value></entry>
       </map>
     </property>
     <property name="relativeOrder">31</property> <!-- [JBDEPLOY-201] workaround -->



More information about the jbossws-commits mailing list
--- stack/cxf/branches/ropalka/modules/server/src/main/java/org/jboss/wsf/stack/cxf/DescriptorDeploymentAspect.java	2009-07-27 08:15:17 UTC (rev 10386)
+++ stack/cxf/branches/ropalka/modules/server/src/main/java/org/jboss/wsf/stack/cxf/DescriptorDeploymentAspect.java	2009-07-27 08:21:15 UTC (rev 10387)
@@ -27,6 +27,7 @@
 import java.util.Map;
 
 import org.jboss.logging.Logger;
+import org.jboss.wsf.common.integration.Constants;
 import org.jboss.wsf.spi.deployment.ArchiveDeployment;
 import org.jboss.wsf.spi.deployment.Deployment;
 import org.jboss.wsf.spi.deployment.DeploymentAspect;
@@ -195,20 +196,21 @@
    }
 
    /**
     * Puts CXF config file to deployment property <b>org.jboss.ws.webapp.ContextParameterMap</b> map
     * @param dep deployment where to put
     * @param cxfURL to be put
     */
    private void putCXFConfigToDeployment(Deployment dep, URL cxfURL)
    {
       // get property map
-      String propKey = "org.jboss.ws.webapp.ContextParameterMap";
-      Map<String, String> contextParams = (Map<String, String>)dep.getProperty(propKey);
+      Map<String, String> contextParams = (Map<String, String>)dep.getProperty(Constants.STACK_CONTEXT_PARAMS);
       if (contextParams == null)
       {
          // if there's no associated map with the property create it now
          contextParams = new HashMap<String, String>();
-         dep.setProperty(propKey, contextParams);
+         dep.setProperty(Constants.STACK_CONTEXT_PARAMS, contextParams);
       }
       // put cxf config URL to the property map
       contextParams.put(CXFServletExt.PARAM_CXF_BEANS_URL, cxfURL.toExternalForm());
@@ -195,20 +196,21 @@
 
    /**
-    * Puts CXF config file to deployment property <b>org.jboss.ws.webapp.ContextParameterMap</b> map
-    * @param dep deployment where to put
-    * @param cxfURL to be put
+    * Puts CXF config file reference to the stack specific context properties. 
+    *
+    * @param dep webservice deployment
+    * @param cxfURL CXF DD URL
+    * @see org.jboss.wsf.common.integration.Constants.STACK_CONTEXT_PARAMS
     */
    private void putCXFConfigToDeployment(Deployment dep, URL cxfURL)

Modified: stack/cxf/branches/ropalka/modules/server/src/main/resources/jbossws-cxf-config.xml
===================================================================